@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
 
 #include <curses.h>
 
-#include <list>
+#include <forward_list>
 
 #include <stdio.h>
 
@@ -30,23 +30,24 @@ struct CustomColor {
 	short color;
 	short r,g,b;
 
-	constexpr CustomColor(short _color, short _r, short _g, short _b)
+	constexpr CustomColor(short _color,
+			      short _r, short _g, short _b) noexcept
 		:color(_color), r(_r), g(_g), b(_b) {}
 };
 
-static std::list<CustomColor> custom_colors;
+static std::forward_list<CustomColor> custom_colors;
 
 /* This function is called from conf.c before curses have been started,
  * it adds the definition to the color_definition_list and init_color() is
  * done in colors_start() */
 void
-colors_define(short color, short r, short g, short b)
+colors_define(short color, short r, short g, short b) noexcept
 {
-	custom_colors.emplace_back(color, r, g, b);
+	custom_colors.emplace_front(color, r, g, b);
 }
 
 void
-ApplyCustomColors()
+ApplyCustomColors() noexcept
 {
 	if (custom_colors.empty())
 		return;
