@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,7 @@
 #include "filelist.hxx"
 #include "Styles.hxx"
 #include "paint.hxx"
-#include "song_paint.hxx"
+#include "SongRowPaint.hxx"
 #include "time_format.hxx"
 #include "util/UriUtil.hxx"
 
