@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,8 @@
 
 #include "Instance.hxx"
 #include "Options.hxx"
-#include "xterm_title.hxx"
+
+#include <signal.h>
 
 Instance::Instance()
 	:io_service(),
