@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,8 +22,10 @@
 
 #include <curses.h>
 
+#include <stdio.h>
+
 const char *
-key2str(int key)
+key2str(int key) noexcept
 {
 	switch(key) {
 		static char buf[32];
