@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,10 +20,11 @@
 #include "ProgressBar.hxx"
 #include "Styles.hxx"
 #include "Options.hxx"
+#include "config.h"
 
 #include <assert.h>
 
-ProgressBar::ProgressBar(Point p, unsigned _width)
+ProgressBar::ProgressBar(Point p, unsigned _width) noexcept
 	:window(p, {_width, 1u})
 {
 	leaveok(window.w, true);
@@ -34,7 +35,7 @@ ProgressBar::ProgressBar(Point p, unsigned _width)
 }
 
 void
-ProgressBar::Paint() const
+ProgressBar::Paint() const noexcept
 {
 	if (max > 0) {
 		assert(width < window.size.width);
@@ -61,7 +62,7 @@ ProgressBar::Paint() const
 }
 
 bool
-ProgressBar::Calculate()
+ProgressBar::Calculate() noexcept
 {
 	if (max == 0)
 		return false;
@@ -74,7 +75,7 @@ ProgressBar::Calculate()
 }
 
 void
-ProgressBar::OnResize(Point p, unsigned _width)
+ProgressBar::OnResize(Point p, unsigned _width) noexcept
 {
 	window.Resize({_width, 1u});
 	window.Move(p);
@@ -83,7 +84,7 @@ ProgressBar::OnResize(Point p, unsigned _width)
 }
 
 bool
-ProgressBar::Set(unsigned _current, unsigned _max)
+ProgressBar::Set(unsigned _current, unsigned _max) noexcept
 {
 	if (_current > _max)
 		_current = _max;
