@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,12 +29,13 @@
 #include "config.h"
 #include "i18n.h"
 #include "charset.hxx"
+#include "Command.hxx"
 #include "Options.hxx"
 #include "mpdclient.hxx"
 #include "strfsong.hxx"
 #include "Completion.hxx"
 #include "Styles.hxx"
-#include "song_paint.hxx"
+#include "SongRowPaint.hxx"
 #include "time_format.hxx"
 #include "screen.hxx"
 #include "screen_utils.hxx"
@@ -258,17 +259,17 @@ class DatabaseCompletion final : public Completion {
 	std::set<std::string> dir_list;
 
 public:
-	explicit DatabaseCompletion(struct mpdclient &_c)
+	explicit DatabaseCompletion(struct mpdclient &_c) noexcept
 		:c(_c) {}
 
 protected:
 	/* virtual methods from class Completion */
-	void Pre(const char *value) override;
-	void Post(const char *value, Range range) override;
+	void Pre(const char *value) noexcept override;
+	void Post(const char *value, Range range) noexcept override;
 };
 
 void
-DatabaseCompletion::Pre(const char *line)
+DatabaseCompletion::Pre(const char *line) noexcept
 {
 	if (empty()) {
 		/* create initial list */
@@ -282,7 +283,7 @@ DatabaseCompletion::Pre(const char *line)
 }
 
 void
-DatabaseCompletion::Post(const char *line, Range range)
+DatabaseCompletion::Post(const char *line, Range range) noexcept
 {
 	if (range.begin() != range.end() &&
 	    std::next(range.begin()) != range.end())
