@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,9 @@
 #include "BasicColors.hxx"
 #include "CustomColors.hxx"
 #include "i18n.h"
+#include "util/RuntimeError.hxx"
 #include "util/StringStrip.hxx"
+#include "util/Compiler.h"
 
 #ifdef ENABLE_COLORS
 #include "Options.hxx"
@@ -29,7 +31,7 @@
 
 #include <assert.h>
 #include <stdio.h>
-#include <stdlib.h>
+#include <strings.h>
 #include <string.h>
 
 /**
@@ -45,12 +47,6 @@ static constexpr short COLOR_NONE = -1;
  */
 static constexpr short COLOR_INHERIT = -2;
 
-/**
- * A magic value for certain parser functions to indicate that the
- * parser has failed to recognize the string.
- */
-static constexpr short COLOR_ERROR = -3;
-
 /**
  * A non-standad magic value which means "inherit attributes from the
  * parent style".
@@ -94,7 +90,7 @@ struct StyleData {
 
 #ifndef ENABLE_COLORS
 	constexpr StyleData(const char *_name, Style,
-			    short, short, attr_t, attr_t _mono)
+			    short, short, attr_t, attr_t _mono) noexcept
 		:name(_name), mono(_mono) {}
 #endif
 };
@@ -192,7 +188,7 @@ static StyleData styles[size_t(Style::END)] = {
 };
 
 static constexpr auto &
-GetStyle(Style style)
+GetStyle(Style style) noexcept
 {
 	return styles[size_t(style)];
 }
@@ -201,7 +197,7 @@ GetStyle(Style style)
 
 gcc_pure
 static Style
-StyleByName(const char *name)
+StyleByName(const char *name) noexcept
 {
 	for (size_t i = 1; i < size_t(Style::END); ++i)
 		if (!strcasecmp(styles[i].name, name))
@@ -211,7 +207,7 @@ StyleByName(const char *name)
 }
 
 static void
-colors_update_pair(Style style)
+colors_update_pair(Style style) noexcept
 {
 	auto &data = GetStyle(style);
 
@@ -240,7 +236,9 @@ colors_update_pair(Style style)
 	init_pair(short(style), fg, bg);
 }
 
-gcc_pure
+/**
+ * Throws on error.
+ */
 static short
 ParseBackgroundColor(const char *s)
 {
@@ -251,10 +249,13 @@ ParseBackgroundColor(const char *s)
 	if (!strcasecmp(s, "none"))
 		return COLOR_NONE;
 
-	return COLOR_ERROR;
+	throw FormatRuntimeError("%s: %s", _("Unknown color"), s);
 }
 
-static bool
+/**
+ * Throws on error.
+ */
+static void
 ParseStyle(StyleData &d, const char *str)
 {
 	std::string copy(str);
@@ -265,14 +266,7 @@ ParseStyle(StyleData &d, const char *str)
 		char *slash = strchr(cur, '/');
 		if (slash != nullptr) {
 			const char *name = slash + 1;
-			short color = ParseBackgroundColor(name);
-			if (color == COLOR_ERROR) {
-				fprintf(stderr, "%s: %s\n",
-					_("Unknown color"), name);
-				return false;
-			}
-
-			d.bg_color = color;
+			d.bg_color = ParseBackgroundColor(name);
 
 			*slash = 0;
 
@@ -314,26 +308,19 @@ ParseStyle(StyleData &d, const char *str)
 			d.attr |= A_DIM;
 		else if (!strcasecmp(cur, "bold"))
 			d.attr |= A_BOLD;
-		else {
-			fprintf(stderr, "%s: %s\n",
-				_("Unknown color"), str);
-			return false;
-		}
-
+		else
+			throw FormatRuntimeError("%s: %s",
+						 _("Unknown color"), str);
 	}
-
-	return true;
 }
 
-bool
+void
 ModifyStyle(const char *name, const char *value)
 {
 	const auto style = StyleByName(name);
-	if (style == Style::END) {
-		fprintf(stderr, "%s: %s\n",
-			_("Unknown color field"), name);
-		return false;
-	}
+	if (style == Style::END)
+		throw FormatRuntimeError("%s: %s",
+					 _("Unknown color field"), name);
 
 	auto &data = GetStyle(style);
 
@@ -342,22 +329,15 @@ ModifyStyle(const char *name, const char *value)
 		   styles inherit their background color from; if the
 		   user configures a color, it will be the background
 		   color, but no attributes */
-		short color = ParseBackgroundColor(value);
-		if (color != COLOR_ERROR) {
-			data.bg_color = color;
-			return true;
-		} else {
-			fprintf(stderr, "%s: %s\n",
-				_("Unknown color"), value);
-			return false;
-		}
+		data.bg_color = ParseBackgroundColor(value);
+		return;
 	}
 
 	return ParseStyle(data, value);
 }
 
 void
-ApplyStyles()
+ApplyStyles() noexcept
 {
 	if (has_colors()) {
 		/* initialize color support */
@@ -380,7 +360,7 @@ ApplyStyles()
 #endif
 
 void
-SelectStyle(WINDOW *w, Style style)
+SelectStyle(WINDOW *w, Style style) noexcept
 {
 	const auto &data = GetStyle(style);
 
