@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
 
 #ifdef ENABLE_NLS
 
-#include <libintl.h>
+#include <libintl.h> // IWYU pragma: export
 
 #define _(x) gettext(x)
 
