@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,26 +18,25 @@
  */
 
 #include "lyrics.hxx"
+#include "plugin.hxx"
 #include "config.h"
 
-#include <assert.h>
-
-static PluginList empty, plugins;
+static PluginList plugins;
 
 void lyrics_init()
 {
-	plugin_list_load_directory(&plugins, LYRICS_PLUGIN_DIR);
+	plugins = plugin_list_load_directory(LYRICS_PLUGIN_DIR);
 }
 
 PluginCycle *
 lyrics_load(boost::asio::io_service &io_service,
 	    const char *artist, const char *title,
-	    plugin_callback_t callback, void *data)
+	    PluginResponseHandler &handler)
 {
+	assert(artist != nullptr);
+	assert(title != nullptr);
+
 	const char *args[3] = { artist, title, nullptr };
 
-	if (artist == nullptr || title == nullptr)
-		return plugin_run(io_service, &empty, args, callback, data);
-
-	return plugin_run(io_service, &plugins, args, callback, data);
+	return plugin_run(io_service, &plugins, args, handler);
 }
