@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 #include "Command.hxx"
 #include "config.h"
 #include "i18n.h"
-#include "charset.hxx"
 #include "mpdclient.hxx"
 #include "Options.hxx"
 #include "DelayedSeek.hxx"
@@ -35,13 +34,10 @@
 
 #include <mpd/client.h>
 
-#include <stdlib.h>
-#include <unistd.h>
 #include <string.h>
-#include <time.h>
 
 ScreenManager::PageMap::iterator
-ScreenManager::MakePage(const PageMeta &sf)
+ScreenManager::MakePage(const PageMeta &sf) noexcept
 {
 	auto i = pages.find(&sf);
 	if (i != pages.end())
@@ -55,7 +51,7 @@ ScreenManager::MakePage(const PageMeta &sf)
 }
 
 void
-ScreenManager::Switch(const PageMeta &sf, struct mpdclient &c)
+ScreenManager::Switch(const PageMeta &sf, struct mpdclient &c) noexcept
 {
 	if (&sf == current_page->first)
 		return;
@@ -79,7 +75,7 @@ ScreenManager::Switch(const PageMeta &sf, struct mpdclient &c)
 }
 
 void
-ScreenManager::Swap(struct mpdclient &c, const struct mpd_song *song)
+ScreenManager::Swap(struct mpdclient &c, const struct mpd_song *song) noexcept
 {
 	if (song != nullptr)
 	{
@@ -100,8 +96,9 @@ ScreenManager::Swap(struct mpdclient &c, const struct mpd_song *song)
 		Switch(*mode_fn_prev, c);
 }
 
+gcc_pure
 static int
-find_configured_screen(const char *name)
+find_configured_screen(const char *name) noexcept
 {
 	unsigned i;
 
@@ -113,7 +110,7 @@ find_configured_screen(const char *name)
 }
 
 void
-ScreenManager::NextMode(struct mpdclient &c, int offset)
+ScreenManager::NextMode(struct mpdclient &c, int offset) noexcept
 {
 	int max = options.screen_list.size();
 
