@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,18 +25,15 @@
 #include "ProxyPage.hxx"
 #include "screen_status.hxx"
 #include "screen_find.hxx"
-#include "screen.hxx"
 #include "KeyName.hxx"
 #include "i18n.h"
-#include "conf.hxx"
+#include "ConfigFile.hxx"
 #include "Bindings.hxx"
 #include "GlobalBindings.hxx"
 #include "screen_utils.hxx"
 #include "Options.hxx"
 #include "util/Compiler.h"
 
-#include <algorithm>
-
 #include <assert.h>
 #include <errno.h>
 #include <string.h>
