@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,6 @@
 
 #include "screen_list.hxx"
 #include "PageMeta.hxx"
-#include "screen.hxx"
 #include "HelpPage.hxx"
 #include "QueuePage.hxx"
 #include "FileBrowserPage.hxx"
@@ -31,6 +30,7 @@
 #include "OutputsPage.hxx"
 #include "ChatPage.hxx"
 #include "util/Macros.hxx"
+#include "config.h"
 
 #include <string.h>
 
