@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,16 +19,12 @@
 
 #include "screen.hxx"
 #include "Page.hxx"
-#include "config.h"
-#include "mpdclient.hxx"
 #include "Options.hxx"
 
-#include <mpd/client.h>
-
 #include <assert.h>
 
 void
-ScreenManager::PaintTopWindow()
+ScreenManager::PaintTopWindow() noexcept
 {
 	const char *title = current_page->second->GetTitle(buf, buf_size);
 	assert(title != nullptr);
@@ -37,7 +33,7 @@ ScreenManager::PaintTopWindow()
 }
 
 void
-ScreenManager::Paint(bool main_dirty)
+ScreenManager::Paint(bool main_dirty) noexcept
 {
 	/* update title/header window */
 	PaintTopWindow();
