@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,13 +24,13 @@
 #include <stdarg.h>
 
 void
-screen_status_message(const char *msg)
+screen_status_message(const char *msg) noexcept
 {
 	screen->status_bar.SetMessage(msg);
 }
 
 void
-screen_status_printf(const char *format, ...)
+screen_status_printf(const char *format, ...) noexcept
 {
 	va_list ap;
 	va_start(ap,format);
