@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2018 The Music Player Daemon Project
+ * (c) 2004-2019 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,20 +19,18 @@
 
 #include "screen_utils.hxx"
 #include "screen.hxx"
-#include "mpdclient.hxx"
 #include "config.h"
 #include "i18n.h"
 #include "Options.hxx"
 #include "Styles.hxx"
 #include "wreadln.hxx"
 #include "ncmpc.hxx"
+#include "config.h"
 
 #ifndef _WIN32
 #include "WaitUserInput.hxx"
 #endif
 
-#include <mpd/client.h>
-
 #include <string.h>
 
 void
